"""
   Copyright 2019-2021 Boris Shminke

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""
from neural_semigroups.associator_loss import AssociatorLoss
from neural_semigroups.constant_baseline import ConstantBaseline
from neural_semigroups.cyclic_group import CyclicGroup
from neural_semigroups.denoising_autoencoder import MagmaDAE
from neural_semigroups.mace4_semigroups_dataset import Mace4Semigroups
from neural_semigroups.magma import Magma
from neural_semigroups.precise_guess_loss import PreciseGuessLoss
from neural_semigroups.semigroups_dataset import SemigroupsDataset
from neural_semigroups.smallsemi_dataset import Smallsemi
